/* Y o u r   D e s c r i p t i o n                       */
/*                            AppBuilder Photon Code Lib */
/*                                         Version 1.13X */

/* Standard headers */
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>

/* Toolkit headers */
#include <Ph.h>
#include <Pt.h>
#include <Ap.h>

/* Local headers */
#include "abimport.h"
#include "proto.h"

#include <photon/PhRender.h> 

#include "global.h"
#include "scaleit.h"

#define T_WIDTH  67
#define T_HEIGHT 47

int
button_hit( PtWidget_t *widget, ApInfo_t *apinfo, PtCallbackInfo_t *cbinfo )

	{
	PtArg_t args[3];
	PhImage_t *label_data, *new_data;
	int ret;

	/* eliminate 'unreferenced' warnings */
	widget = widget, apinfo = apinfo, cbinfo = cbinfo;

	PtSetArg( &args[0], Pt_ARG_LABEL_DATA, &label_data, 0 );
	PtGetResources( ABW_thumb, 1, args);

	new_data = (PhImage_t *)malloc( sizeof( PhImage_t ));
	if ( new_data ) {
		memcpy( new_data, label_data, sizeof( PhImage_t ));
	
		ret = ScaleImage( bgimage, new_data, T_WIDTH, T_HEIGHT, 
                          bytes_per_pixel );

		PtSetArg(&args[0], Pt_ARG_LABEL_DATA, new_data, sizeof(*new_data));
		PtSetResources( ABW_thumb, 1, args);
	}

    return( Pt_CONTINUE ); 
	}

/* Scale a PhImage_t structure ...

be careful: - you need to use the same bytes_per_pixel between images. you
              also need to have the same image type.
            - the size of the thumbnail should be the same as the width and
              height passed in... 
*/


int
ScaleImage(PhImage_t *image,       /* image to be scaled */
           PhImage_t *thumbnail,   /* thumbnail destination */
           int width, int height,  /* size of thumb */
           int bpp )               /* bytes per pixel */
{
	unsigned char *out, *pin, *ndata;
	int xratio, yratio;
	int bits[] = {128, 64, 32, 16, 8, 4, 2, 1};

	if ( width == 0 || height == 0 )
		return( -1 );
	
	xratio = FPDIV(image->size.w << 16, width << 16);
	yratio = FPDIV(image->size.h << 16, height << 16);

	if (image->colors)
	{
		int x, y;
		char *p, *o, *q;

		/*
		** If there's a mask with this image, we need to
		** transform it as well
		*/

		ndata = (char *)malloc( height * width);
		if( !ndata ) 
			return( -1 );
					
		for (y = 0; y < height; y++) {
			o = ndata + (width * y);
			q = p = image->image + (image->bpl * (FPMUL(y<<16, yratio) >> 16));
			for (x = 0; x < width; x++) {
				q = p + (FPMUL(x << 16, xratio) >> 16);
				*o++ = *q;
			}
		}
	}
	else
	{
		int x, y;
		int Width = bpp * image->size.w;
		int nw = bpp * width;
		
		ndata = (char *)malloc( height * width * bpp);
		if ( !ndata )  
			return ( -1 ); 				
		out = (unsigned char *) ndata;
		pin = (unsigned char *) image->image;

		for (y = 0; y < height; y++) {
			int yoff = (FPMUL( y << 16, yratio ) >> 16) * Width;
			for (x = 0; x < width; x++) {
				int off, off2;
				off2 = yoff + (FPMUL(x << 16,xratio) >> 16) * bpp;

				off = y * nw + (x * bpp);

				out[off] = pin[off2];
				out[off+1] = pin[off2+1];
				out[off+2] = pin[off2+2];
			}
		}
	}
	memcpy( thumbnail->image, ndata, (T_WIDTH * T_HEIGHT * bpp) );

	if ( ndata )
		free( ndata );
    
	return (0);
}

