/* Y o u r   D e s c r i p t i o n                       */
/*                            AppBuilder Photon Code Lib */
/*                                         Version 1.13X */

/* Standard headers */
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>

/* Toolkit headers */
#include <Ph.h>
#include <Pt.h>
#include <Ap.h>

#include <photon/PhRender.h> 

/* Local headers */
#include "abimport.h"
#include "proto.h"

/* Application Options string */
const char ApOptions[] =
	AB_OPTIONS ""; /* Add your options in the "" */

#define PX_IMAGE_MODULES
#define PX_BMP_SUPPORT
#define PX_JPG_SUPPORT
#include <photon/PxImage.h>

#define DEFINE_GLOBALS
#include <limits.h>
#include "global.h"

void * memory_allocate( long nbytes, int type )
{
	return( PgShmemCreate( nbytes, NULL ) );
}

void memory_free( void *memory, int type )
{
	PgShmemDestroy( memory );
}

int
init( int argc, char *argv[] )

	{

	/* eliminate 'unreferenced' warnings */
	argc = argc, argv = argv;

	image_path = (char *)malloc(_MAX_PATH);
	if ( image_path == NULL ) {
		printf("out of memory\n");
		exit(0);
	}

	/* find path to where we are and store in global 'image_path' */
    find_execute_path( argv[0], image_path );

    load_images();

	return( Pt_CONTINUE );

	}


void
load_images()
{
	PxMethods_t methods;
	char buff[_MAX_PATH];

	memset( &methods, 0, sizeof( PxMethods_t ) );
	methods.px_alloc    = memory_allocate;
	methods.px_free     = memory_free;
    methods.flags       |= PX_LOAD;

	sprintf( buff, "%s%s", image_path, "bgimage_24.bmp" );
	if (!(bgimage = \
      PxLoadImage( buff, &methods )))
	{
		printf("Error getting image.. %s\n", buff);
		exit(0);
	}
	sprintf( buff, "%s%s", image_path, "thumbnail.bmp" );
	if (!(thumbnail = \
      PxLoadImage( buff, &methods )))
	{
		printf("Error getting image.. %s\n", buff);
		exit(0);
	}

	bytes_per_pixel = 3;    // force it to 3
}

int
base_setup( PtWidget_t *link_instance, ApInfo_t *apinfo, PtCallbackInfo_t *cbinfo )

	{
	PtArg_t arg[1];

	PtSetArg( &arg[0], Pt_ARG_BKGD_IMAGE, bgimage, sizeof( PhImage_t ) );
	PtSetResources( ABW_bkgd1, 1, arg );

	PtSetArg( &arg[0], Pt_ARG_LABEL_DATA, thumbnail, sizeof( PhImage_t) );
	PtSetResources( ABW_thumb, 1, arg );

	return( Pt_CONTINUE );

	}

/* take the full path to where we currently are based on current search
   criteria.
   Then truncate to just after the last / in this pathname.
   e.g.

   passing in /test/progs/file as orig_path will return
     /test/progs/ in exec_path
*/

int
find_execute_path( char *orig_path, char *exec_path )
{
char buff[_MAX_PATH];     /* working buffer */
char *p;

    _searchenv( basename( orig_path ), "PATH", buff );

	p = strrchr( buff, '/' );
    if ( p == NULL )
		strcpy( exec_path, "./" );   /* give it the current directory */
	else 
		/* only copy to after the '/' */
		strncpy( exec_path, buff, p - buff + 1 );  

	return( 0 );
}

